# coding: utf-8

"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 2.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_metadata_service_async_client.api.healthcheck_api import HealthcheckApi


class TestHealthcheckApi(unittest.IsolatedAsyncioTestCase):
    """HealthcheckApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = HealthcheckApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_health(self) -> None:
        """Test case for get_health

        Perform a Health Check
        """
        pass


if __name__ == '__main__':
    unittest.main()
